@@ -5,7 +5,7 @@ From https://github.com/nonhermitian/qiskit_sphinx_theme.
 """
 from os import path
 
-__version__ = '0.0.24'
+__version__ = '1.6.1'
 __version_full__ = __version__
 
 
@@ -17,3 +17,6 @@ def get_html_theme_path():
 # See http://www.sphinx-doc.org/en/stable/theming.html#distribute-your-theme-as-a-python-package
 def setup(app):
     app.add_html_theme('qiskit_sphinx_theme', path.abspath(path.dirname(__file__)))
+
+    # return explicit parallel safe
+    return {'parallel_read_safe': True, 'parallel_write_safe': True}
